@@ -29,7 +29,9 @@ class FlatMapStrategy(SearchStrategy):
         super(FlatMapStrategy, self).__init__()
         self.flatmapped_strategy = strategy
         self.expand = expand
-        self.is_empty = strategy.is_empty
+
+    def calc_is_empty(self, recur):
+        return recur(self.flatmapped_strategy)
 
     def __repr__(self):
         if not hasattr(self, u'_cached_repr'):
@@ -40,7 +42,6 @@ class FlatMapStrategy(SearchStrategy):
 
     def do_draw(self, data):
         source = data.draw(self.flatmapped_strategy)
-        data.mark_bind()
         return data.draw(self.expand(source))
 
     @property
